@@ -2,7 +2,7 @@ package WebService::Stripe;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.1100'; # VERSION
+our $VERSION = '1.0000'; # VERSION
 
 use Carp qw(croak);
 use HTTP::Request::Common qw( POST );
@@ -56,7 +56,7 @@ method get_customer(Str $id, :$headers) {
     return $self->get( "/v1/customers/$id", {}, headers => $headers );
 }
 
-method update_customer(Str $id, HashRef $data, :$headers) {
+method update_customer(Str $id, HashRef :$data!, :$headers) {
     return $self->post( "/v1/customers/$id", $data, headers => $headers );
 }
 
@@ -78,7 +78,7 @@ method create_charge(HashRef $data, :$headers) {
     return $self->post( "/v1/charges", $data, headers => $headers );
 }
 
-method update_charge(HashRef|Str $charge, HashRef $data, :$headers) {
+method update_charge(HashRef|Str $charge, HashRef :$data!, :$headers) {
     $charge = $charge->{id} if ref $charge;
     return $self->post( "/v1/charges/$charge", $data, headers => $headers );
 }
@@ -117,6 +117,10 @@ method get_account(Str $id, :$headers) {
     return $self->get( "/v1/accounts/$id", {}, headers => $headers );
 }
 
+method get_platform_account(:$headers) {
+    return $self->get( "/v1/account", {}, headers => $headers );
+}
+
 method update_account(Str $id, HashRef :$data!, :$headers) {
     return $self->post( "/v1/accounts/$id", $data, headers => $headers );
 }
@@ -173,6 +177,12 @@ method cancel_transfer(Str $id, :$headers) {
     return $self->post("/v1/transfers/$id/cancel", undef, headers => $headers);
 }
 
+method create_reversal($xfer_id, HashRef :$data = {}, HashRef :$headers = {}) {
+    return $self->post("/v1/transfers/$xfer_id/reversals", $data,
+        headers => $headers,
+    );
+}
+
 method get_bitcoin_receivers(HashRef :$query, :$headers) {
     return $self->get( "/v1/bitcoin/receivers", $query, headers => $headers );
 }
@@ -202,7 +212,7 @@ WebService::Stripe - Stripe API bindings
 
 =head1 VERSION
 
-version 0.1100
+version 1.0000
 
 =head1 SYNOPSIS
 
@@ -267,14 +277,14 @@ Example:
 
 =head2 update_customer
 
-    update_customer($id, $data)
+    update_customer($id, data => $data)
 
 Updates a customer.
 Returns the updated customer.
 
 Example:
 
-    $customer = $stripe->update_customer($id, { description => 'foo' });
+    $customer = $stripe->update_customer($id, data => { description => 'foo' });
 
 =head2 get_customers
 
@@ -338,7 +348,7 @@ The data param is optional.
 
 =head2 update_charge
 
-    update_charge($id, $data)
+    update_charge($id, data => $data)
 
 Updates an existing charge object.
 
@@ -368,6 +378,10 @@ Adds a new funding source (credit card) to an existing customer.
 
     update_account($id, data => $data)
 
+=head2 get_platform_account
+
+    get_platform_account($id)
+
 =head2 upload_identity_document
 
 Uploads a photo ID to an account.
@@ -445,6 +459,31 @@ Example:
 
     cancel_transfer($id)
 
+=head2 create_reversal
+
+Reverses an existing transfer.
+
+L<Stripe Documentation|https://stripe.com/docs/api/python#transfer_reversals>
+
+Example:
+
+    $ws_stripe->create_reversal(
+        # Transfer ID (required)
+        $xfer_id,
+        data => {
+            # POST data (optional)
+            refund_application_fee        => 'true',
+            amount                        => 100,
+            description                   => 'Invoice Correction',
+            'metadata[local_reversal_id]' => 'rvrsl_123',
+            'metadata[requester]'         => 'John Doe'
+        },
+        headers => {
+            # Headers (optional)
+            stripe_account => $account->{'id'}
+        }
+    );
+
 =head2 get_balance
 
     get_balance()
